@@ -1,4 +1,4 @@
-# Copyright 2024 The etils Authors.
+# Copyright 2025 The etils Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,13 +29,20 @@ import traceback
 from typing import Any, Optional, Tuple
 
 from etils import enp
-
+from etils import epy
 from etils.epy import _internal
 
 with _internal.check_missing_deps():
   # pylint: disable=g-import-not-at-top
   import IPython
   import IPython.display
+  # pylint: enable=g-import-not-at-top
+
+
+with epy.lazy_imports(
+    error_callback='Use `pip install etils[ecolab]` to install missing deps'
+):
+  # pylint: disable=g-import-not-at-top
   import mediapy as media
   # pylint: enable=g-import-not-at-top
 
