@@ -1,4 +1,4 @@
-# Copyright 2024 The etils Authors.
+# Copyright 2025 The etils Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -128,7 +128,14 @@ def resource_path(package: Union[str, types.ModuleType]) -> abstract_path.Path:
     # a non-path object, so convert manually.
     # Note this is not the true path (`/google_src/` vs
     # `/export/.../server/ml_notebook.runfiles`), but should be equivalent.
-    path = pathlib.Path(sys.modules[package].__file__)
+    # TODO(b/390190120): Note that `module.__name__` behave inconsistently.
+    if isinstance(package, types.ModuleType):
+      path = package.__file__
+    elif isinstance(package, str):
+      path = sys.modules[package].__file__
+    else:
+      raise TypeError(f'Unknown package type: {type(package)}: {package}')
+    path = pathlib.Path(path)
     if path.name == '__init__.py':
       path = path.parent
 
