@@ -1,4 +1,4 @@
-# Copyright 2024 The etils Authors.
+# Copyright 2025 The etils Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -76,6 +76,11 @@ class StrEnum(*_StrEnum):
       return False
     return other.lower() == self.value.lower()
 
+  # `__ne__` is required because `str.__ne__()` exists, so it is not
+  # automatically inferred.
+  def __ne__(self, other: str) -> bool:
+    return not self.__eq__(other)
+
   def __hash__(self) -> int:  # pylint: disable=useless-super-delegation
     # Somehow `hash` is not defined automatically (maybe because of
     # the `__eq__`, so define it explicitly.
