@@ -1,4 +1,4 @@
-# Copyright 2024 The etils Authors.
+# Copyright 2025 The etils Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 
 from __future__ import annotations
 
+import collections
 import contextlib
 import dataclasses
 import difflib
@@ -70,7 +71,6 @@ class Lines:
       b=2,
   )
   ```
-
   """
 
   def __init__(self, *, indent: int = 4):
@@ -271,7 +271,7 @@ def pretty_repr_top_level(obj: Any, *, force: bool = False) -> str:
     return lines
   elif type(obj) is dict:  # pylint: disable=unidiomatic-typecheck
     return Lines.make_block(
-        content={repr(k): v for k, v in obj.items()},
+        content={pretty_repr(k): v for k, v in obj.items()},
         braces='{',
         equal=': ',
     )
@@ -286,6 +286,15 @@ def pretty_repr_top_level(obj: Any, *, force: bool = False) -> str:
             if field.repr
         },
     )
+  elif _is_pydantic(obj, force=force):
+    return Lines.make_block(
+        header=obj.__class__.__name__,
+        content={
+            field_name: getattr(obj, field_name)
+            for field_name, field_info in obj.model_fields.items()
+            if field_info.repr
+        },
+    )
   elif _is_attr(obj, force=force):
     import attr  # pylint: disable=g-import-not-at-top  # pytype: disable=import-error
 
@@ -299,6 +308,45 @@ def pretty_repr_top_level(obj: Any, *, force: bool = False) -> str:
             if field.repr
         },
     )
+  elif _is_immutabledict(obj, force=force):
+    return Lines.make_block(
+        header=obj.__class__.__name__,
+        content={pretty_repr(k): v for k, v in obj.items()},
+        braces=('({', '})'),
+        equal=': ',
+    )
+  elif _is_userdict(obj, force=force):
+    return Lines.make_block(
+        header=obj.__class__.__name__,
+        content={pretty_repr(k): v for k, v in obj.items()},
+        braces=('({', '})'),
+        equal=': ',
+    )
+  # TODO(epot): When the new fiddle version is release on PyPI, this
+  # code could be activated (with the matching test).
+  elif _is_fiddle(obj):
+    import fiddle  # pylint: disable=g-import-not-at-top  # pytype: disable=import-error
+
+    cls_name = type(obj).__name__
+    formatted_fn_or_cls = obj._fn_or_cls_name_repr()  # pylint: disable=protected-access
+
+    formatted_params = []
+    for name, tags, value in obj._params_name_tags_and_value():  # pylint: disable=protected-access
+      if not tags and value is fiddle.NO_VALUE:
+        continue
+
+      param_str = str(name)
+      if tags:
+        param_str += f"[{', '.join(sorted(str(tag) for tag in tags))}]"
+      if value is not fiddle.NO_VALUE:
+        param_str += f'={pretty_repr(value)}'
+      formatted_params.append(_Repr(param_str))
+
+    return Lines.make_block(
+        header=f'<{cls_name}[{formatted_fn_or_cls}',
+        content=formatted_params,
+        braces=('(', ')]>'),
+    )
   else:
     return repr(obj)
 
@@ -322,7 +370,7 @@ def _is_datclass(obj: Any, *, force: bool = False) -> bool:
     return False
   if not dataclasses.is_dataclass(obj):
     return False
-  if force:
+  if force:  # Force pretty-print even if custom `__repr__`
     return True
   if not obj.__dataclass_params__.repr:  # dataclass(repr=False)
     return False
@@ -344,7 +392,7 @@ def _is_attr(obj: Any, *, force: bool = False) -> bool:
 
   if not attr.has(type(obj)):
     return False
-  if force:
+  if force:  # Force pretty-print even if custom `__repr__`
     return True
   if not (doc := type(obj).__repr__.__doc__):
     return False
@@ -353,6 +401,48 @@ def _is_attr(obj: Any, *, force: bool = False) -> bool:
   return True
 
 
+def _is_pydantic(obj: Any, *, force: bool = False) -> bool:
+  """Returns `True` if the object is a `pydantic` dataclass."""
+  if 'pydantic' not in sys.modules:
+    return False
+
+  import pydantic  # pylint: disable=g-import-not-at-top  # pytype: disable=import-error
+
+  if not isinstance(obj, pydantic.BaseModel):
+    return False
+  if force:  # Force pretty-print even if custom `__repr__`
+    return True
+  if type(obj).__repr__ == pydantic.BaseModel.__repr__:  # Default repr
+    return True
+  return False  # Custom repr, do not pretty-print
+
+
+def _is_immutabledict(obj: Any, *, force: bool = False) -> bool:
+  """Returns `True` if the object is an `immutabledict`."""
+  if 'immutabledict' not in sys.modules:
+    return False
+  import immutabledict  # pylint: disable=g-import-not-at-top  # pytype: disable=import-error
+
+  if not isinstance(obj, immutabledict.immutabledict):
+    return False
+  if force:  # Force pretty-print even if custom `__repr__`
+    return True
+  if type(obj).__repr__ == immutabledict.immutabledict.__repr__:  # Default repr
+    return True
+  return False  # Custom repr, do not pretty-print
+
+
+def _is_userdict(obj: Any, *, force: bool = False) -> bool:
+  """Returns `True` if the object is a `collections.UserDict`."""
+  if not isinstance(obj, collections.UserDict):
+    return False
+  if force:  # Force pretty-print even if custom `__repr__`
+    return True
+  if type(obj).__repr__ == collections.UserDict.__repr__:  # Default repr
+    return True
+  return False  # Custom repr, do not pretty-print
+
+
 def _is_fiddle(obj: Any) -> bool:
   """Returns `True` if the object is a `fiddle` config object."""
   if 'fiddle' not in sys.modules:
